==> elgg-1.12.12.zip: elgg-1.12.12/mod/groups/languages/pt_br.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Comunidades",
	'groups:owned' => "Comunidades que possuo",
	'groups:owned:user' => 'Donos das comunidades %s',
	'groups:yours' => "Minhas Comunidades",
	'groups:user' => "Comunidades de %s",
	'groups:all' => "Todas as Comunidades do site",
	'groups:add' => "Criar uma nova comunidade",
	'groups:edit' => "Editar Comunidade",
	'groups:delete' => 'Apagar Comunidade',
	'groups:membershiprequests' => 'Gerenciar solicitações de entrada',
	'groups:membershiprequests:pending' => 'Gerencia solicitação de inclusões (%s)',
	'groups:invitations' => 'Convites da Comunidade',
	'groups:invitations:pending' => 'Convites das comunidades (%s)',

	'groups:icon' => 'Ícone da Comunidade (deixe em branco para não alterar)',
	'groups:name' => 'Nome da Comunidade',
	'groups:username' => 'Apelido da Comunidade (exibido nas URLs, apenas caracteres alfanuméricos)',
	'groups:description' => 'Descrição',
	'groups:briefdescription' => 'Breve descrição',
	'groups:interests' => 'Descritores (Tags)',
	'groups:website' => 'Sites',
	'groups:members' => 'Pessoas da Comunidade',
	'groups:my_status' => 'Meu status',
	'groups:my_status:group_owner' => 'Você é o dono desta comunidade',
	'groups:my_status:group_member' => 'Você está nesta comunidade',
	'groups:subscribed' => 'Notificação de comunidade ativa',
	'groups:unsubscribed' => 'Notificação de comunidade inativa',

	'groups:members:title' => 'Pessoas de %s',
	'groups:members:more' => "Ver mais pessoas",
	'groups:membership' => "Permissões de adesão para a Comunidade",
	'groups:content_access_mode' => "Acessibilidade do conteúdo da comunidade",
	'groups:content_access_mode:warning' => "Aviso: Alterando esta configuração não será mudada a permissão de acesso do conteúdo  existente da comunidade.",
	'groups:content_access_mode:unrestricted' => "Irrestrito - Acesso depende da configuração definida a nível de conteúdo.",
	'groups:content_access_mode:membersonly' => "Somente membros - Pessoas não associadas nunca poderão acessar o conteúdo da comunidade.",
	'groups:access' => "Permissões de acesso",
	'groups:owner' => "Proprietário",
	'groups:owner:warning' => "Aviso: se você alterar este valor, você não será mais o dono desta comunidade.",
	'groups:widget:num_display' => 'Número de Comunidades a serem exibidas',
	'groups:widget:membership' => 'Participante da Comunidade',
	'groups:widgets:description' => 'Exibir em seu perfil as Comunidades das quais você participa',

	'groups:widget:group_activity:title' => 'Atividade na comunidade',
	'groups:widget:group_activity:description' => 'Visualize a atividade em uma das suas comunidades',
	'groups:widget:group_activity:edit:select' => 'Selecione uma comunidade',
	'groups:widget:group_activity:content:noactivity' => 'Não existe nenhuma atividade neste grupo.',
	'groups:widget:group_activity:content:noselect' => 'Edite este dispositivo para selecionar uma comunidade',

	'groups:noaccess' => 'Sem acesso para a Comunidade',
	'groups:permissions:error' => 'Você não possui permissão para isso',
	'groups:ingroup' => 'na comunidade',
	'groups:cantcreate' => 'Você não pode criar uma comunidade.  Somente administradores podem fazer isso.',
	'groups:cantedit' => 'Você não pode editar esta Comunidade',
	'groups:saved' => 'Comunidade salva',
	'groups:save_error' => 'Group could not be saved',
	'groups:featured' => 'Comunidades em destaque',
	'groups:makeunfeatured' => 'Sem destaques',
	'groups:makefeatured' => 'Destacar',
	'groups:featuredon' => 'Você destacou esta Comunidade.',
	'groups:unfeatured' => '%s foi removido do destaque desta Comunidade.',
	'groups:featured_error' => 'Comunidade inválida.',
	'groups:nofeatured' => 'Nenhuma comunidade em destaque',
	'groups:joinrequest' => 'Solicitar inclusão como pessoa',
	'groups:join' => 'Participar desta Comunidade',
	'groups:leave' => 'Sair da Comunidade',
	'groups:invite' => 'Convidar amigos',
	'groups:invite:title' => 'Convidar amigos para esta comunidade',
	'groups:inviteto' => "Convidar amigos para '%s'",
	'groups:nofriends' => "Você não possui amigos que ainda não tenham sido convidados para esta Comunidade.",
	'groups:nofriendsatall' => 'Você não possui amigos para convidar!',
	'groups:viagroups' => "pelas Comunidades",
	'groups:group' => "Comunidade",
	'groups:search:tags' => "descritor (tag)",
	'groups:search:title' => "Pesquise por comunidades que contenham o descritor '%s'",
	'groups:search:none' => "Nenhuma comunidade compatível foi encontrada",
	'groups:search_in_group' => "Pesquise nesta comunidade",
	'groups:acl' => "Comunidade: %s",

	'discussion:topic:notify:summary' => 'Novo tópico de discussão chamado  %s',
	'discussion:topic:notify:subject' => 'Novo tópico de discussão: %s',
	'discussion:topic:notify:body' =>
'%s adicionou um novo tópico de discussão na comunidade %s:

Título: %s

%s

Visualize e responda ao tópico de discussão:
%s
',

	'discussion:reply:notify:summary' => 'Nova resposta ao tópico: %s',
	'discussion:reply:notify:subject' => 'Nova resposta ao tópico: %s',
	'discussion:reply:notify:body' =>
'%s respondeu ao tópico de discussão %s na comunidade %s

%s

Visualize e responda na discussão:
%s
',

	'groups:activity' => "Atividade na comunidade",
	'groups:enableactivity' => 'Habilita atividade na comunidade',
	'groups:activity:none' => "Nenhuma atividade na comunidade ainda.",

	'groups:notfound' => "Comunidade não encontrada",
	'groups:notfound:details' => "A comunidade procurada não existe ou você não possui permissão de acesso para ela.",

	'groups:requests:none' => 'Não existem solicitações de participação neste momento.',

	'groups:invitations:none' => 'Não existem convites neste momento.',

	'item:object:groupforumtopic' => "Tópicos em debate",
	'item:object:discussion_reply' => "Respostas às discussões",

	'groupforumtopic:new' => "Nova mensagem de discussão",

	'groups:count' => "Comunidades criadas",
	'groups:open' => "Comunidade aberta",
	'groups:closed' => "Comunidade fechada",
	'groups:member' => "pessoas",
	'groups:searchtag' => "Pesquisar Comunidades por descritor (tag)",

	'groups:more' => 'Mais comunidades',
	'groups:none' => 'Nenhuma comunidade',

	/**
	 * Access
	 */
	'groups:access:private' => 'Fechado - usuário deve ser convidado',
	'groups:access:public' => 'Aberto - Qualquer usuário pode participar',
	'groups:access:group' => 'Somente pessoas da comunidade',
	'groups:closedgroup' => "Esta Comunidade possui participação fechada. ",
	'groups:closedgroup:request' => 'Para solicitar para ser incluído, click em "Solicitar inclusão como pessoa" no menu.',
	'groups:closedgroup:membersonly' => "Participação como membros desta comunidade é fechado e este conteúdo é acessível apenas para membros.",
	'groups:opengroup:membersonly' => "O conteúdo da comunidade é acessível apenas para membros.",
	'groups:opengroup:membersonly:join' => 'Para se tornar membro, selecione o link do menu "Entrar para comunidade"',
	'groups:visibility' => 'Quem pode visualizar este Comunidade?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Habilitar discussões na Comunidade',
	'groups:lastupdated' => 'Última atualização %s por %s',
	'groups:lastcomment' => 'Último comentário %s por %s ',

	/**
	 * Group discussion
	 */
	'discussion' => 'Discussão',
	'discussion:add' => 'Adicionar tópico para discussão',
	'discussion:latest' => 'Última discussão',
	'discussion:group' => 'Discussão da comunidade',
	'discussion:none' => 'Sem discussões',
	'discussion:reply:title' => 'Responder para %s',

	'discussion:topic:created' => 'O tópico de discussão foi criado.',
	'discussion:topic:updated' => 'O tópico de discussão foi atualizado.',
	'discussion:topic:deleted' => 'O tópico de discussão foi apagado.',

	'discussion:topic:notfound' => 'Tópico de discussão não encontrado',
	'discussion:error:notsaved' => 'Não foi possível salvar este tópico',
	'discussion:error:missing' => 'Ambos campos, titulo e mensagem, são obrigatórios',
	'discussion:error:permissions' => 'Você não possui permissão para executar esta ação',
	'discussion:error:notdeleted' => 'Não foi possível apagar este tópico de discussão',

	'discussion:reply:edit' => 'Editar resposta',
	'discussion:reply:deleted' => 'Resposta da discussão foi apagada.',
	'discussion:reply:error:notfound' => 'A resposta a discussão não foi encontrada',
	'discussion:reply:error:notfound_fallback' => "Desculpe, não foi possível encontrar a reposta especificada, mas nós temos encaminhado a você ao tópico de discussão original.",
	'discussion:reply:error:notdeleted' => 'Não foi possivel apagar a resposta da discussão',

	'discussion:search:title' => 'Responda no tópico: %s',
	
	'admin:groups' => 'Comunidades',

	'reply:this' => 'Responder',

	'group:replies' => 'Respostas',
	'groups:forum:created' => 'Cirado %s com %d comentários',
	'groups:forum:created:single' => 'Criado %s com %d respostas',
	'groups:forum' => 'Discussão',
	'groups:addtopic' => 'Adicionar tópico',
	'groups:forumlatest' => 'Última discussão',
	'groups:latestdiscussion' => 'Última discussão',
	'groupspost:success' => 'Seu resposta foi enviada com sucesso.',
	'groupspost:failure' => 'Aconteceu um problema ao enviar sua resposta',
	'groups:alldiscussion' => 'Última discussão',
	'groups:edittopic' => 'Editar tópico',
	'groups:topicmessage' => 'Mensagem do tópico',
	'groups:topicstatus' => 'Situação do tópico',
	'groups:reply' => 'Enviar um mensagem',
	'groups:topic' => 'Tópico',
	'groups:posts' => 'Mensagens',
	'groups:lastperson' => 'Última pessoa',
	'groups:when' => 'Quando',
	'grouptopic:notcreated' => 'Nenhum tópico foi criado.',
	'groups:topicclosed' => 'Fechado',
	'grouptopic:created' => 'Seu tópico foi criado.',
	'groups:topicsticky' => 'Adesivo',
	'groups:topicisclosed' => 'Este tópico está fechado.',
	'groups:topiccloseddesc' => 'Este tópico agora está fechado e não aceita novos comentários.',
	'grouptopic:error' => 'Não foi possível criar o tópico em seu Comunidade. Por favor, tente novamente ou entre em contato com o administrador da comunidade.',
	'groups:forumpost:edited' => "Você editou com sucesso a mensagem deste fórum.",
	'groups:forumpost:error' => "Houve um problema ao editar a mensagem deste fórum.",

	'groups:privategroup' => 'Este Comunidade é fechada. Solicite ao moderador sua participação.',
	'groups:notitle' => 'Comunidades devem ter um título',
	'groups:cantjoin' => 'Não foi possível participar da Comunidade',
	'groups:cantleave' => 'Não foi possível deixar a Comunidade',
	'groups:removeuser' => 'Remover da comunidade',
	'groups:cantremove' => 'Não foi possível remover usuário da comunidade',
	'groups:removed' => 'Removido %s com sucesso da comunidade',
	'groups:addedtogroup' => 'Usuário adicionado com sucesso na Comunidade',
	'groups:joinrequestnotmade' => 'Não foi possível solicitar a participação na Comunidade',
	'groups:joinrequestmade' => 'Foi solicitada a entrada na Comunidade',
	'groups:joined' => 'Participação na Comunidade realizada com sucesso!',
	'groups:left' => 'Você deixou a Comunidade com sucesso!',
	'groups:notowner' => 'Desculpe, mas você não é o proprietário desta Comunidade.',
	'groups:notmember' => 'Desculpe, mas você não faz parte desta Comunidade.',
	'groups:alreadymember' => 'Você já faz parte desta Comunidade!',
	'groups:userinvited' => 'Convite enviado com sucesso.',
	'groups:usernotinvited' => 'O convite não pode ser enviado.',
	'groups:useralreadyinvited' => 'Este usuário já foi convidado para participar desta Comunidade',
	'groups:invite:subject' => "%s você foi convidado a entrar na Comunidade %s!",
	'groups:updated' => "Último comentário por %s %s",
	'groups:started' => "Iniciado por %s",
	'groups:joinrequest:remove:check' => 'Você tem certeza de que deseja apagar esta solicitação de participação?',
	'groups:invite:remove:check' => 'Você tem certeza de que deseja apagar este convite de participação?',
	'groups:invite:body' => "Olá %s,

%s convidou você para participar da Comunidade '%s', clique abaixo para confirmar:

%s",

	'groups:welcome:subject' => "Seja bem-vindo na Comunidade %s!",
	'groups:welcome:body' => "Olá %s!

Agora você é membro da Comunidade '%s'! Clique abaixo para começar a enviar mensagens!

%s",

	'groups:request:subject' => "%s solicitou a participação na Comunidade %s",
	'groups:request:body' => "Olá %s,

%s solicitou a participação na Comunidade '%s', clique abaixo para ver seu perfil:

%s

ou clique abaixo para aceitar o pedido:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s criou a comunidade ',
	'river:join:group:default' => '%s se juntou a comunidade %s',
	'river:create:object:groupforumtopic' => '%s adicionou um novo tópico de discussão %s',
	'river:reply:object:groupforumtopic' => '%s respondeu ao tópico de discussão %s',
	'river:reply:view' => 'Visualiza resposta',

	'groups:nowidgets' => 'Nenhum dispositivo foi definido para esta Comunidade.',


	'groups:widgets:members:title' => 'Participantes da Comunidade',
	'groups:widgets:members:description' => 'Listar os participantes de uma Comunidade.',
	'groups:widgets:members:label:displaynum' => 'Listar os participantes de uma Comunidade.',
	'groups:widgets:members:label:pleaseedit' => 'Por favor, configure este dispositivo.',

	'groups:widgets:entities:title' => "Objetos na Comunidade",
	'groups:widgets:entities:description' => "Listar os objetos salvos nesta Comunidade",
	'groups:widgets:entities:label:displaynum' => 'Listar os objetos de uma Comunidade.',
	'groups:widgets:entities:label:pleaseedit' => 'Por favor, configure este dispositivo.',

	'groups:forumtopic:edited' => 'Tópico do fórum editado com sucesso.',

	'groups:allowhiddengroups' => 'Você deseja permitir Comunidades privadas (invisíveis)?',
	'groups:whocancreate' => 'Quem pode criar novas comunidades?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'A Comunidade e todo seu conteúdo foram apagados com sucesso.',
	'group:notdeleted' => 'Não foi possível apagar a Comunidade',

	'group:notfound' => 'Não foi possível encontrar a Comunidade',
	'grouppost:deleted' => 'Mensagem na Comunidade apagada com sucesso.',
	'grouppost:notdeleted' => 'Não foi possível apagar a mensagem da Comunidade.',
	'groupstopic:deleted' => 'Tópico apagado com sucesso',
	'groupstopic:notdeleted' => 'Não foi possível apagar o tópico',
	'grouptopic:blank' => 'Nenhum tópico',
	'grouptopic:notfound' => 'Não foi possível encontrar o tópico',
	'grouppost:nopost' => 'Mensagem vazia',
	'groups:deletewarning' => "Você tem certeza de que deseja apagar esta Comunidade? Não será possível desfazer esta ação!",

	'groups:invitekilled' => 'O convite foi apagado.',
	'groups:joinrequestkilled' => 'O pedido de participação foi apagado.',
	'groups:error:addedtogroup' => "Não foi possível adicionar %s na comunidade",
	'groups:add:alreadymember' => "%s já é um participante desta comunidade",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Discussões da Comunidade',
	'groups:ecml:groupprofile' => 'Perfis da Comunidade',
);

==> elgg-2.3.5.zip: elgg-2.3.5/mod/groups/languages/pt_br.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Comunidades",
	'groups:owned' => "Comunidades que possuo",
	'groups:owned:user' => 'Donos das comunidades %s',
	'groups:yours' => "Minhas Comunidades",
	'groups:user' => "Comunidades de %s",
	'groups:all' => "Todas as Comunidades do site",
	'groups:add' => "Criar uma nova comunidade",
	'groups:edit' => "Editar Comunidade",
	'groups:delete' => 'Apagar Comunidade',
	'groups:membershiprequests' => 'Gerenciar solicitações de entrada',
	'groups:membershiprequests:pending' => 'Gerencia solicitação de inclusões (%s)',
	'groups:invitations' => 'Convites da Comunidade',
	'groups:invitations:pending' => 'Convites das comunidades (%s)',

	'groups:icon' => 'Ícone da Comunidade (deixe em branco para não alterar)',
	'groups:name' => 'Nome da Comunidade',
	'groups:username' => 'Apelido da Comunidade (exibido nas URLs, apenas caracteres alfanuméricos)',
	'groups:description' => 'Descrição',
	'groups:briefdescription' => 'Breve descrição',
	'groups:interests' => 'Descritores (Tags)',
	'groups:website' => 'Sites',
	'groups:members' => 'Pessoas da Comunidade',
	'groups:my_status' => 'Meu status',
	'groups:my_status:group_owner' => 'Você é o dono desta comunidade',
	'groups:my_status:group_member' => 'Você está nesta comunidade',
	'groups:subscribed' => 'Group notifications are on',
	'groups:unsubscribed' => 'Group notifications are off',

	'groups:members:title' => 'Pessoas de %s',
	'groups:members:more' => "Ver mais pessoas",
	'groups:membership' => "Permissões de adesão para a Comunidade",
	'groups:content_access_mode' => "Acessibilidade do conteúdo da comunidade",
	'groups:content_access_mode:warning' => "Aviso: Alterando esta configuração não será mudada a permissão de acesso do conteúdo  existente da comunidade.",
	'groups:content_access_mode:unrestricted' => "Irrestrito - Acesso depende da configuração definida a nível de conteúdo.",
	'groups:content_access_mode:membersonly' => "Somente membros - Pessoas não associadas nunca poderão acessar o conteúdo da comunidade.",
	'groups:access' => "Permissões de acesso",
	'groups:owner' => "Proprietário",
	'groups:owner:warning' => "Aviso: se você alterar este valor, você não será mais o dono desta comunidade.",
	'groups:widget:num_display' => 'Número de Comunidades a serem exibidas',
	'groups:widget:membership' => 'Participante da Comunidade',
	'groups:widgets:description' => 'Exibir em seu perfil as Comunidades das quais você participa',

	'groups:widget:group_activity:title' => 'Atividade na comunidade',
	'groups:widget:group_activity:description' => 'Visualize a atividade em uma das suas comunidades',
	'groups:widget:group_activity:edit:select' => 'Selecione uma comunidade',
	'groups:widget:group_activity:content:noactivity' => 'Não existe nenhuma atividade neste grupo.',
	'groups:widget:group_activity:content:noselect' => 'Edite este dispositivo para selecionar uma comunidade',

	'groups:noaccess' => 'Sem acesso para a Comunidade',
	'groups:ingroup' => 'na comunidade',
	'groups:cantcreate' => 'Você não pode criar uma comunidade.  Somente administradores podem fazer isso.',
	'groups:cantedit' => 'Você não pode editar esta Comunidade',
	'groups:saved' => 'Comunidade salva',
	'groups:save_error' => 'Group could not be saved',
	'groups:featured' => 'Comunidades em destaque',
	'groups:makeunfeatured' => 'Sem destaques',
	'groups:makefeatured' => 'Destacar',
	'groups:featuredon' => 'Você destacou esta Comunidade.',
	'groups:unfeatured' => '%s foi removido do destaque desta Comunidade.',
	'groups:featured_error' => 'Comunidade inválida.',
	'groups:nofeatured' => 'Nenhuma comunidade em destaque',
	'groups:joinrequest' => 'Solicitar inclusão como pessoa',
	'groups:join' => 'Participar desta Comunidade',
	'groups:leave' => 'Sair da Comunidade',
	'groups:invite' => 'Convidar amigos',
	'groups:invite:title' => 'Convidar amigos para esta comunidade',
	'groups:inviteto' => "Convidar amigos para '%s'",
	'groups:nofriends' => "Você não possui amigos que ainda não tenham sido convidados para esta Comunidade.",
	'groups:nofriendsatall' => 'Você não possui amigos para convidar!',
	'groups:viagroups' => "pelas Comunidades",
	'groups:group' => "Comunidade",
	'groups:search:tags' => "descritor (tag)",
	'groups:search:title' => "Pesquise por comunidades que contenham o descritor '%s'",
	'groups:search:none' => "Nenhuma comunidade compatível foi encontrada",
	'groups:search_in_group' => "Pesquise nesta comunidade",
	'groups:acl' => "Comunidade: %s",

	'groups:activity' => "Atividade na comunidade",
	'groups:enableactivity' => 'Habilita atividade na comunidade',
	'groups:activity:none' => "Nenhuma atividade na comunidade ainda.",

	'groups:notfound' => "Comunidade não encontrada",
	'groups:notfound:details' => "A comunidade procurada não existe ou você não possui permissão de acesso para ela.",

	'groups:requests:none' => 'Não existem solicitações de participação neste momento.',

	'groups:invitations:none' => 'Não existem convites neste momento.',

	'groups:count' => "Comunidades criadas",
	'groups:open' => "Comunidade aberta",
	'groups:closed' => "Comunidade fechada",
	'groups:member' => "pessoas",
	'groups:searchtag' => "Pesquisar Comunidades por descritor (tag)",

	'groups:more' => 'Mais comunidades',
	'groups:none' => 'Nenhuma comunidade',

	/**
	 * Access
	 */
	'groups:access:private' => 'Fechado - usuário deve ser convidado',
	'groups:access:public' => 'Aberto - Qualquer usuário pode participar',
	'groups:access:group' => 'Somente pessoas da comunidade',
	'groups:closedgroup' => "Esta Comunidade possui participação fechada. ",
	'groups:closedgroup:request' => 'Para solicitar para ser incluído, click em "Solicitar inclusão como pessoa" no menu.',
	'groups:closedgroup:membersonly' => "Participação como membros desta comunidade é fechado e este conteúdo é acessível apenas para membros.",
	'groups:opengroup:membersonly' => "O conteúdo da comunidade é acessível apenas para membros.",
	'groups:opengroup:membersonly:join' => 'Para se tornar membro, selecione o link do menu "Entrar para comunidade"',
	'groups:visibility' => 'Quem pode visualizar este Comunidade?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => 'Última atualização %s por %s',
	'groups:lastcomment' => 'Último comentário %s por %s ',

	'admin:groups' => 'Comunidades',

	'groups:privategroup' => 'Este Comunidade é fechada. Solicite ao moderador sua participação.',
	'groups:notitle' => 'Comunidades devem ter um título',
	'groups:cantjoin' => 'Não foi possível participar da Comunidade',
	'groups:cantleave' => 'Não foi possível deixar a Comunidade',
	'groups:removeuser' => 'Remover da comunidade',
	'groups:cantremove' => 'Não foi possível remover usuário da comunidade',
	'groups:removed' => 'Removido %s com sucesso da comunidade',
	'groups:addedtogroup' => 'Usuário adicionado com sucesso na Comunidade',
	'groups:joinrequestnotmade' => 'Não foi possível solicitar a participação na Comunidade',
	'groups:joinrequestmade' => 'Foi solicitada a entrada na Comunidade',
	'groups:joined' => 'Participação na Comunidade realizada com sucesso!',
	'groups:left' => 'Você deixou a Comunidade com sucesso!',
	'groups:notowner' => 'Desculpe, mas você não é o proprietário desta Comunidade.',
	'groups:notmember' => 'Desculpe, mas você não faz parte desta Comunidade.',
	'groups:alreadymember' => 'Você já faz parte desta Comunidade!',
	'groups:userinvited' => 'Convite enviado com sucesso.',
	'groups:usernotinvited' => 'O convite não pode ser enviado.',
	'groups:useralreadyinvited' => 'Este usuário já foi convidado para participar desta Comunidade',
	'groups:invite:subject' => "%s você foi convidado a entrar na Comunidade %s!",
	'groups:started' => "Iniciado por %s",
	'groups:joinrequest:remove:check' => 'Você tem certeza de que deseja apagar esta solicitação de participação?',
	'groups:invite:remove:check' => 'Você tem certeza de que deseja apagar este convite de participação?',
	'groups:invite:body' => "Olá %s,

%s convidou você para participar da Comunidade '%s', clique abaixo para confirmar:

%s",

	'groups:welcome:subject' => "Seja bem-vindo na Comunidade %s!",
	'groups:welcome:body' => "Olá %s!

Agora você é membro da Comunidade '%s'! Clique abaixo para começar a enviar mensagens!

%s",

	'groups:request:subject' => "%s solicitou a participação na Comunidade %s",
	'groups:request:body' => "Olá %s,

%s solicitou a participação na Comunidade '%s', clique abaixo para ver seu perfil:

%s

ou clique abaixo para aceitar o pedido:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s criou a comunidade ',
	'river:join:group:default' => '%s se juntou a comunidade %s',

	'groups:nowidgets' => 'Nenhum dispositivo foi definido para esta Comunidade.',


	'groups:widgets:members:title' => 'Participantes da Comunidade',
	'groups:widgets:members:description' => 'Listar os participantes de uma Comunidade.',
	'groups:widgets:members:label:displaynum' => 'Listar os participantes de uma Comunidade.',
	'groups:widgets:members:label:pleaseedit' => 'Por favor, configure este dispositivo.',

	'groups:widgets:entities:title' => "Objetos na Comunidade",
	'groups:widgets:entities:description' => "Listar os objetos salvos nesta Comunidade",
	'groups:widgets:entities:label:displaynum' => 'Listar os objetos de uma Comunidade.',
	'groups:widgets:entities:label:pleaseedit' => 'Por favor, configure este dispositivo.',

	'groups:allowhiddengroups' => 'Você deseja permitir Comunidades privadas (invisíveis)?',
	'groups:whocancreate' => 'Quem pode criar novas comunidades?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'A Comunidade e todo seu conteúdo foram apagados com sucesso.',
	'group:notdeleted' => 'Não foi possível apagar a Comunidade',

	'group:notfound' => 'Não foi possível encontrar a Comunidade',
	'groups:deletewarning' => "Você tem certeza de que deseja apagar esta Comunidade? Não será possível desfazer esta ação!",

	'groups:invitekilled' => 'O convite foi apagado.',
	'groups:joinrequestkilled' => 'O pedido de participação foi apagado.',
	'groups:error:addedtogroup' => "Não foi possível adicionar %s na comunidade",
	'groups:add:alreadymember' => "%s já é um participante desta comunidade",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Perfis da Comunidade',
);
